PluginProbe
AcyMailing – An Ultimate Newsletter Plugin and Marketing Automation Solution for WordPress / 10.11.1
AcyMailing – An Ultimate Newsletter Plugin and Marketing Automation Solution for WordPress v10.11.1
11.1.1 11.1.0 11.0.5 11.0.4 11.0.3 11.0.2 11.0.1 11.0.0 10.11.1 10.11.0 10.10.2 10.10.1 10.10.0 10.9.1 trunk 10.0.0 10.0.1 10.1.0 10.1.1 10.1.2 10.1.3 10.1.4 10.2.0 10.2.1 10.2.2 All 62 releases
acymailing / back / Views / Stats / tmpl / global_stats_data.php

global_stats_data.php in AcyMailing – An Ultimate Newsletter Plugin and Marketing Automation Solution for WordPress 10.11.1, at back/Views/Stats/tmpl/global_stats_data.php

214 lines 10.0 KB
No matching file
Up and down to move Enter to open Esc to close
Raw Download Zip
1 <div class="acym__content acym__stats grid-x cell">
2 <input type="hidden" name="time_linechart" id="acym__time__linechart__input">
3 <div class="cell acym__stats__campaign-choose margin-bottom-1 large-3 medium-4 small-12">
4 <?php if ($data['page_title']) { ?>
5 <h2 class="acym__title"><?php echo acym_translation('ACYM_GLOBAL_STATISTICS'); ?></h2>
6 <?php } ?>
7 </div>
8 <div class="large-9 medium-8 small-12 margin-bottom-1 cell acym__stats__export grid-x align-right grid-margin-x">
9 <?php if (!$data['page_title']) { ?>
10 <div class="cell small-5 medium-4 large-3 xlarge-2">
11 <?php
12 echo acym_select(
13 [
14 'charts' => acym_translation('ACYM_CHARTS'),
15 'formatted' => acym_translation('ACYM_FORMATTED_DATA'),
16 'full' => acym_translation('ACYM_FULL_DATA'),
17 ],
18 'export_type',
19 'charts',
20 ['class' => 'acym__select']
21 );
22 ?>
23 </div>
24 <?php
25 echo acym_tooltip([
26 'hoveredText' => '<button type="button" class="cell shrink button primary acym__stats__export__button acym__stats__export__global__charts " data-task="exportGlobal">'
27 .acym_translation('ACYM_EXPORT').'</button>',
28 'textShownInTooltip' => acym_translation('ACYM_STATS_EXPORT_SETTINGS_TOOLTIP'),
29 ]);
30 } ?>
31 </div>
32 <?php if (!empty($data['selectedMailid']) && !empty($data['lists'])) { ?>
33 <div class="cell grid-x margin-bottom-1">
34 <h2 class="cell shrink acym__title acym__title__secondary"><?php echo acym_translation('ACYM_RECEIVER_LISTS'); ?></h2>
35 <div class="cell grid-x auto margin-left-1">
36 <?php
37 foreach ($data['lists'] as $list) {
38 echo acym_tooltip(
39 [
40 'hoveredText' => '<i style="color: '.$list->color.'" class="acym_subscription acymicon-circle"></i>',
41 'textShownInTooltip' => $list->name,
42 ]
43 );
44 }
45 ?>
46 </div>
47 <h2 class="cell acym__title acym__title__secondary">
48 <?php echo acym_translationSprintf('ACYM_NUMBER_OF_RECEIVERS_X', $data['mail']->sent); ?>
49 </h2>
50 </div>
51 <?php } ?>
52 <?php if (empty($data['sentMails'])) { ?>
53 <h2 class="acym__listing__empty__title text-center cell margin-bottom-1">
54 <?php echo acym_translation('ACYM_DONT_HAVE_STATS_CAMPAIGN'); ?>
55 <a href="<?php echo acym_completeLink('campaigns&task=edit&step=chooseTemplate'); ?>"><?php echo acym_translation('ACYM_CREATE_ONE'); ?></a>
56 </h2>
57 <?php } ?>
58 <div class="cell grid-x grid-margin-y" id="acym__stats__export__global__charts__scope">
59 <div class="cell grid-x acym__content acym__stats__donut__chart align-center">
60 <h2 class="cell acym__title acym__title__secondary"><?php echo acym_translation('ACYM_EMAIL_STATISTICS'); ?></h2>
61 <?php if (empty($data['sentMails'])) { ?>
62 <h4 class="cell acym__subtitle__stats text-center"><b><?php echo acym_translation('ACYM_LOOK_AT_THESE_AMAZING_DONUTS'); ?></b></h4>
63 <?php } ?>
64 <div class="acym__stats__donut__one-chart cell large-2 medium-4 small-12">
65 <?php
66 echo acym_roundChart(
67 $data['mail']->percentageSent,
68 'delivery',
69 '',
70 acym_tooltip(
71 [
72 'hoveredText' => acym_translation('ACYM_SUCCESSFULLY_SENT'),
73 'textShownInTooltip' => $data['mail']->allSent,
74 ]
75 )
76 ); ?>
77 </div>
78 <div class="acym__stats__donut__one-chart cell large-2 medium-4 small-12">
79 <?php
80 echo acym_roundChart(
81 $data['mail']->percentageOpen,
82 'open',
83 '',
84 acym_tooltip(
85 [
86 'hoveredText' => acym_translation('ACYM_OPEN_RATE'),
87 'textShownInTooltip' => $data['mail']->allOpen,
88 ]
89 )
90 ); ?>
91 </div>
92 <div class="acym__stats__donut__one-chart cell large-2 medium-4 small-12">
93 <?php
94 echo acym_roundChart(
95 $data['mail']->percentageClick,
96 'click',
97 '',
98 acym_tooltip(
99 [
100 'hoveredText' => acym_translation('ACYM_CLICK_RATE'),
101 'textShownInTooltip' => $data['mail']->allClick,
102 ]
103 )
104 ); ?>
105 </div>
106 <div class="acym__stats__donut__one-chart cell large-2 medium-4 small-12">
107 <?php
108 echo acym_roundChart(
109 $data['mail']->percentageBounce,
110 'bounce',
111 '',
112 acym_tooltip(
113 [
114 'hoveredText' => acym_translation('ACYM_BOUNCE_RATE'),
115 'textShownInTooltip' => $data['mail']->allBounce,
116 ]
117 )
118 ); ?>
119 </div>
120 <?php if (!empty($data['selectedMailid'])) { ?>
121 <div class="acym__stats__donut__one-chart cell large-2 medium-4 small-12">
122 <?php
123 echo acym_roundChart(
124 $data['mail']->percentageUnsub,
125 'unsubscribe',
126 '',
127 acym_tooltip(
128 [
129 'hoveredText' => acym_translation('ACYM_UNSUBSCRIBE_RATE'),
130 'textShownInTooltip' => $data['mail']->allUnsub,
131 ]
132 )
133 ); ?>
134 </div>
135 <?php } ?>
136 </div>
137 <div class="cell grid-x acym__content acym__stats__pie__chart">
138 <h2 class="cell acym__title acym__title__secondary"><?php echo acym_translation('ACYM_OPENING_PLATFORMS'); ?></h2>
139 <?php if (empty($data['devices'])) { ?>
140 <h4 class="cell acym__subtitle__stats text-center"><b><?php echo acym_translation('ACYM_EMAIL_NOT_OPEN_EXAMPLE_STATS'); ?></b></h4>
141 <div class="cell large-3 hide-for-small-only hide-for-medium-only"></div>
142 <div class="acym__stats__pie__one-chart cell large-3 medium-6">
143 <?php echo $data['example_devices_chart']; ?>
144 </div>
145 <div class="acym__stats__pie__one-chart cell large-3 medium-6">
146 <?php echo $data['example_source_chart']; ?>
147 </div>
148 <div class="cell large-3 hide-for-small-only hide-for-medium-only"></div>
149 <?php } else { ?>
150 <div class="cell large-3 hide-for-small-only hide-for-medium-only"></div>
151 <div class="acym__stats__pie__one-chart cell large-3 medium-6">
152 <?php echo acym_pieChart($data['devices'], 'devices', acym_translation('ACYM_DEVICES')); ?>
153 </div>
154 <div class="acym__stats__pie__one-chart cell large-3 medium-6">
155 <?php echo acym_pieChart($data['openedWith'], 'opened_with', acym_translation('ACYM_OPENED_WITH')); ?>
156 </div>
157 <div class="cell large-3 hide-for-small-only hide-for-medium-only"></div>
158 <?php } ?>
159 </div>
160 <div class="cell acym__content grid-x">
161 <h2 class="cell shrink acym__title acym__title__secondary">
162 <?php echo acym_translation('ACYM_OPEN_TIME_CHART').acym_info(['textShownInTooltip' => 'ACYM_OPEN_TIME_CHART_DESC']); ?>
163 </h2>
164 <?php if ($data['empty_open']) { ?>
165 <h4 class="cell acym__subtitle__stats text-center"><b><?php echo acym_translation('ACYM_EMAIL_NOT_OPEN_EXAMPLE_STATS'); ?></b></h4>
166 <?php } ?>
167 <div class="cell grid-x" id="acym__stats__global__open-time">
168 <input type="hidden" id="acym__stats__global__open-time__data" value="<?php echo acym_escape(json_encode($data['openTime'])); ?>">
169 <canvas id="chartjs-0" height="400" width="400"></canvas>
170 </div>
171 </div>
172 <div class="cell grid-x acym__content acym__stats__chart__line">
173 <h2 class="cell acym__title acym__title__secondary"><?php echo acym_translation('ACYM_OPEN_CLICK_RATE'); ?></h2>
174 <?php if (!$data['mail']->hasStats) { ?>
175 <h4 class="acym__subtitle__stats cell text-center">
176 <b><?php echo acym_translation('ACYM_YOU_DONT_HAVE_ANY_OPEN_CLIC_DATA_YET'); ?></b>
177 <br>
178 <?php echo acym_translation('ACYM_HERE_AN_EXEMPLE_OF_WHAT_YOU_CAN_GET'); ?>
179 </h4>
180 <?php
181 echo $data['example_line_chart'];
182 } else {
183 if ($data['show_date_filters']) {
184 ?>
185 <div class="cell grid-x margin-bottom-1">
186 <div class="cell large-auto "></div>
187 <label class="cell grid-x large-3 medium-6 small-12 acym__stats__chart__date ">
188 <p class="cell shrink"><?php echo acym_translation('ACYM_START'); ?></p>
189 <input
190 class="acy_date_picker auto cell text-center acym__stats__chart__line__input__date"
191 id="chart__line__start"
192 type="text"
193 data-acym-translate="0"
194 data-start="<?php echo acym_escape($data['mail']->startEndDateHour['start']); ?>">
195 </label>
196 <label class="cell grid-x large-3 medium-6 small-12 acym__stats__chart__date ">
197 <p class="cell shrink"><?php echo acym_translation('ACYM_END'); ?></p>
198 <input
199 class="acy_date_picker auto cell text-center acym__stats__chart__line__input__date"
200 id="chart__line__end"
201 type="text"
202 data-acym-translate="0"
203 data-end="<?php echo acym_escape($data['mail']->startEndDateHour['end']); ?>">
204 </label>
205 </div>
206 <?php } ?>
207 <div id="acym__stats__chart__line__canvas" class="cell">
208 <?php echo acym_lineChart($data['mail']->month, $data['mail']->day, $data['mail']->hour); ?>
209 </div>
210 <?php } ?>
211 </div>
212 </div>
213 </div>
214